#[non_exhaustive]pub struct ListNamedQueriesOutputBuilder { /* private fields */ }Expand description
A builder for ListNamedQueriesOutput.
Implementations
Sourceimpl ListNamedQueriesOutputBuilder
impl ListNamedQueriesOutputBuilder
Sourcepub fn named_query_ids(self, input: impl Into<String>) -> Self
pub fn named_query_ids(self, input: impl Into<String>) -> Self
Appends an item to named_query_ids.
To override the contents of this collection use set_named_query_ids.
The list of unique query IDs.
Sourcepub fn set_named_query_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_named_query_ids(self, input: Option<Vec<String>>) -> Self
The list of unique query IDs.
Sourcepub fn get_named_query_ids(&self) -> &Option<Vec<String>>
pub fn get_named_query_ids(&self) -> &Option<Vec<String>>
The list of unique query IDs.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn build(self) -> ListNamedQueriesOutput
pub fn build(self) -> ListNamedQueriesOutput
Consumes the builder and constructs a ListNamedQueriesOutput.